.. meta::
   :description: How-to guides for using the responsible AI toolbox (rai-toolbox).

.. _toolbox-how-to:

How-To Guides
=============

These how-to guides are here to help rAI-toolbox users who are wondering: 
"How do I ___?". Our guides help you learn by having you do; they provide simple steps 
towards concrete objectives.

.. toctree::
   :maxdepth: 1
   :caption: How to...

   how_to/custom_optim
   how_to/univ_adv_pert
   how_to/hydraddp
   how_to/deterministic_workflow
